/*
 * Copyright 2015, Broadcom Corporation
 * All Rights Reserved.
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Broadcom Corporation;
 * the contents of this file may not be disclosed to third parties, copied
 * or duplicated in any form, in whole or in part, without the prior
 * written permission of Broadcom Corporation.
 */

/** @file
*
* BLE Observer Tool
*
* Listens to all adv: non-discoverable, limited discoverable, and general discoverable
*
*/

#include <string.h>
#include "wiced_bt_dev.h"
#include "wiced_bt_ble.h"
#include "wiced_bt_gatt.h"
#include "wiced_bt_cfg.h"
#include "wiced.h"
#include "bt_target.h"
#include "wiced_bt_stack.h"
#include "gattdefs.h"
#include "sdpdefs.h"

//#define FILTER_ADDRESSES

#ifdef FILTER_ADDRESSES
#define MAX_ADDR_COUNT 		2 //change this to accomodate the number of addrs to listen for
#define BD_ADDR_SIZE 		6
#endif

/******************************************************************************
 *                           Function Prototypes
 ******************************************************************************/
static wiced_result_t           hello_sensor_management_callback                ( wiced_bt_management_evt_t event, wiced_bt_management_evt_data_t *p_event_data );

/******************************************************************************
 *                                Variables Definitions
 ******************************************************************************/
extern const wiced_bt_cfg_settings_t wiced_bt_cfg_settings;
extern const wiced_bt_cfg_buf_pool_t wiced_bt_cfg_buf_pools[];

//Add here the addresses you want to listen for
#ifdef FILTER_ADDRESSES
UINT8 BD_ADDRS[MAX_ADDR_COUNT][BD_ADDR_SIZE] = {
		{0xaa, 0xbb, 0xcc, 0xdd, 0xee, 0xff},
		{0x11, 0x22, 0x33, 0x44, 0x55, 0x66},
};
#endif

/******************************************************************************
 *                          Function Definitions
 ******************************************************************************/

/*
 *  Entry point to the application. Set device configuration and start BT
 *  stack initialization.  The actual application initialization will happen
 *  when stack reports that BT device is ready.
 */

void application_start( void )
{

    WPRINT_BT_APP_INFO( ( "Hello Sensor Start\n" ) );

    /* Register call back and configuration with stack */
    wiced_bt_stack_init( hello_sensor_management_callback ,
                    &wiced_bt_cfg_settings, wiced_bt_cfg_buf_pools );
}


static void ble_scan_results_cb( wiced_bt_ble_scan_results_t* p_scan_result, uint8_t* p_adv_data ) {

	uint8_t * bda;

    if ( p_scan_result != NULL )
    {

    	bda = p_scan_result->remote_bd_addr;

#ifdef FILTER_ADDRESSES
    	int i = 0;

    	for(i = 0; i < MAX_ADDR_COUNT; i++)
    	{

    		if(memcmp(bda, BD_ADDRS[i], BD_ADDR_SIZE) == 0)
    		{

#endif

    			WPRINT_APP_INFO(("address:%x %x %x %x %x %x rssi:%d addr type:%d event type:%x\n",
    								bda[0],
    								bda[1],
    								bda[2],
    								bda[3],
    								bda[4],
    								bda[5],
    								p_scan_result->rssi,
    								p_scan_result->ble_addr_type,
    								p_scan_result->ble_evt_type));

#ifdef FILTER_ADDRESSES
    			return;
    		}
    	}
#endif
    }

}


/*
 * hello_sensor bt/ble link management callback
 */
static wiced_result_t hello_sensor_management_callback( wiced_bt_management_evt_t event, wiced_bt_management_evt_data_t *p_event_data )
{
    wiced_result_t                    result = WICED_BT_SUCCESS;

    WPRINT_BT_APP_INFO(("hello_sensor_management_callback: %x\n", event ));

    switch( event )
    {
    /* Bluetooth  stack enabled */
    case BTM_ENABLED_EVT:
    	wiced_bt_ble_observe (WICED_TRUE, 250, ble_scan_results_cb);
        break;

    case BTM_DISABLED_EVT:
        break;

    case BTM_BLE_SCAN_STATE_CHANGED_EVT:
    	printf("wiced_bt_ble_get_current_scan_state = %u\n", wiced_bt_ble_get_current_scan_state());
    	break;

    default:
        break;
    }

    return result;
}


